.. |license| image:: https://img.shields.io/pypi/l/necrypt
    :target: https://pypi.python.org/pypi/necrypt
    :alt: PyPI - License

*******
Necrypt
*******

|license|

Necrypt provides method which generate new cipher for each encryption.

Installation
============

.. code-block:: bash

    pip install necrypt
